pub struct LoadedNativePlugin { /* private fields */ }Implementations
Sourceimpl LoadedNativePlugin
impl LoadedNativePlugin
pub fn plugin_id(&self) -> &str
pub fn plugin_name(&self) -> &str
pub fn diagnostics(&self) -> &[PluginInterfaceDiagnostic]
pub fn interfaces(&self) -> &[PluginInterfaceRecord]
pub fn unknown_interfaces( &self, ) -> impl Iterator<Item = &PluginInterfaceMetadata>
pub fn resolve_post_download( &self, reference: &PluginReference, ) -> Result<Arc<dyn PostDownloadProcessor>, PluginSelectionError>
pub fn resolve_pipeline_event_hook( &self, reference: &PluginReference, ) -> Result<Arc<dyn PipelineEventHook>, PluginSelectionError>
pub fn resolve_benchmark_sink( &self, reference: &PluginReference, ) -> Result<Arc<dyn BenchmarkSink>, PluginSelectionError>
pub fn resolve_native_decoder( &self, reference: &PluginReference, ) -> Result<Arc<dyn NativeDecoderPluginFactory>, PluginSelectionError>
pub fn resolve_frame_processor( &self, reference: &PluginReference, ) -> Result<Arc<dyn FrameProcessorPluginFactory>, PluginSelectionError>
pub fn resolve_audio_processor( &self, reference: &PluginReference, ) -> Result<Arc<dyn AudioProcessorPluginFactory>, PluginSelectionError>
pub fn resolve_source_packet( &self, reference: &PluginReference, ) -> Result<Arc<dyn SourceNormalizerPacketPluginFactory>, PluginSelectionError>
pub fn resolve_source_resource( &self, reference: &PluginReference, ) -> Result<Arc<dyn SourceNormalizerResourcePluginFactory>, PluginSelectionError>
Sourceimpl LoadedNativePlugin
impl LoadedNativePlugin
Sourcepub fn load_development(path: impl AsRef<Path>) -> Result<Self, PluginLoadError>
pub fn load_development(path: impl AsRef<Path>) -> Result<Self, PluginLoadError>
Loads and validates one unsigned native plugin for explicit development or inspection workflows.
The mapped library remains alive for the process lifetime, including
when symbol resolution or root validation fails after dlopen.